@@ -36,7 +36,7 @@ class DialogHelp(wx.Dialog):
         btn.SetDefault()
         win = TestHtmlPanel(self, size = kwds["size"]) 
         dbox.Add(win, 1, wx.EXPAND)
-        dbox.Add(btn, 0, wx.EXPAND)
+        dbox.Add(btn, 0, wx.CENTER | wx.TOP | wx.BOTTOM,border = 4)
         self.SetSizer(dbox)
         #self.SetAutoLayout(True) #sizes it properly...
         dbox.SetSizeHints(self) #made it variable size, stops at 'size' as a min.
