@@ -278,9 +278,9 @@ class OpentypeItem( FontItem ):
         FontItem.__init__( self, glyphpaf )
       
 class Type1Item( FontItem ):
-    def __init__( self, glyphpaf, pfmpaf ):
+    def __init__( self, glyphpaf, metricpaf=None ):
         FontItem.__init__( self, glyphpaf )
-        self.pfmpaf = pfmpaf
+        self.metricpaf = metricpaf
         
 def itemGenerator( fromObj, sourceList ):
     """
@@ -295,105 +295,107 @@ def itemGenerator( fromObj, sourceList ):
     
     listOfItemsGenerated = []
     
+    ## So, [paf,paf,paf,paf,paf] comes in.
     
-    ## The sourceList that comes in MUST be exactly like 
-    ## one that os.listdir() would supply.
-    ## When this is called from Folder, all is well.
-    
-    ## When this is called from Pog, we have fetched a list
-    ## of pafs from a text file. 
-    ## For the Type1 special case, this means that the PFM 
-    ## files are missing. (PFM goes with PFB and we only record
-    ## the PFB files in the Pog text file.)
-    ## They *may* or may not actually exist as files and
-    ## we need to go and look for them.
-    
-    ## This is horribly complicated and really needs an overhaul...
+    ## If it comes from FOLDER then it's full of ALL the files in a single dir.
+    ##  NB: It may or may not include 'type1' files and their 'metrics'
     
+    ## If it comes from POG then it's just pafs of the basic glyph files
+    ## thus it does not include the afm/pfm files.
+    ##  So: this is a special case.
+    ##  We must "fill-up" the list with the 'metric' files that are matched
+    ##  to Type1 files - i.e. AFM and PFM files that belong to the fonts 
+    ##  of type 'type1' which we are detecting by extension as ".pfb" and ".pfa"
     if isinstance( fromObj, Pog ):
-        ## Any PFB files in sourceList?
-        pfblist = [f for f in sourceList if ext(f) == "PFB" ]
-        if pfblist: # Yes, so find the related PFM files
-            ## Each of them may be in their own directory, so we must loop
-            for pfbpaf in pfblist:
-                ## paf : /some/path/somefont.pfb
-                originalDir = os.path.dirname( pfbpaf ) # /some/path
-                filename = os.path.basename( pfbpaf ) # somefont.pfb
-                pfbfilename = stripExt( filename ) # somefont
-                wildcard = os.path.join( originalDir, pfbfilename + u".[Pp][Ff][Mm]" )
-                listOfpfms = glob.glob( wildcard )
-                ## I am only looking for one match
-                thePFM = None
-                for pfmpaf in listOfpfms:
-                    if pfbfilename in pfmpaf:
-                        thePFM = pfmpaf
-                        break
-                if thePFM:
-                    ## We have found a PFM that matches the filename of the PFB
-                    sourceList.append( thePFM )
+        tmp = []
+        for paf in sourceList:
+            ## paf : /some/path/somefont.pfb (or .ttf, or whatever. Do them all.)
+            tmp.append( paf ) # add it to what will replace sourceList
+            dir = os.path.dirname( paf ) # /some/path
+            filename = os.path.basename( paf ) # somefont.pfb
+            ## Find metric files with his name in his dir
+            wild = os.path.join( dir, stripExt(filename) + ".[PpAa][Ff][Mm]" )
+            metricfiles = glob.glob( wild )
+            ## Add what we find (if anything) to the tmp list
+            for metric in metricfiles:
+                tmp.append( metric ) # merge them in
+        ## Replace the sourceList
+        del( sourceList )
+        sourceList = tmp
     
-    ## Make a unique list of all PFM or PFB files in sourceList and strip the extensions.
-    ## This results in only those paths/to/files that are unique files and I will call them
-    ## a "font group". They have the same path and the same filename.
-    ## I don't grok the set() stuff, but it seems to strip duplicates out and that's what
-    ## I want.
-    ## I have to strip the extension because, with it, it makes each string unique anyway.
-    ## I want to identify /some/path/file1.pfb and /some/path/file1.pfm as /some/path/file1
-    ## So this halves the number of Type1 related entries in the list.
-    T1FontGroupNamesOnly = \
-    list( set( [ stripExt(f) for f in sourceList if ( ext(f) == "PFB" or ext(f) =="PFM" ) ] ) )
+    ## Now we have a sourceList that is complete - full of files
     
-    ## Do we have any Type1 nonsense to work out?
-    if len(T1FontGroupNamesOnly) > 0: #yes.
-        ## I can't find any clever way to do this. 
-        ## I want a list like so:
-        ## [ ["PFM", paf], ["PFB", paf] ]
-        ##
-        ## It *may* also happen that there is no PFM file at all...
-        for pafstub in T1FontGroupNamesOnly:
-            tmp=[]
-            for paf in sourceList:
-                if paf.find(pafstub) != -1:
-                    tmp.append( [ext(paf), paf ] )
-            ## tmp is the business
-            ## Now to make a single Type1Item from this list:
-            d = dict(tmp) # cool.
-            p = None
-            if "PFM" in d: p = d["PFM"]
-            fi = Type1Item( d["PFB"], pfmpaf = p )
-            #if fi.badfont:
-                #fi = InfoFontItem( "BADFONT", d["PFB"] )
-            listOfItemsGenerated.append(fi)
-            # Jeezuz that only took me 3 days to work out. Man I'm slow.
-            
+    ## TYPE1 stuff. 10 Jan 2008
+    ## Jump through hoops to find the 'metric' files (AFM then PFM)
+    ## for each Type1 font that's in the list
+    ##
+    ## As per advice on the freetype list I am doing this:
+    ## For every PFA/PFB file, I look for a matching path and filename
+    ## starting with AFM extensions, then trying PFM extensions.
+    ## AFM is preferred over PFM.
+    ## Make Type1Item objects and associate the 'metric' file found (or none)
+    
+    ## Filter some lists from sourceList to step through:
+    PFABs= [[stripExt(e),e] for e in sourceList if ext(e) in ("PFA","PFB")] # all type1 files
+    AFMs = [[stripExt(e),e] for e in sourceList if ext(e) in ("AFM")] # all AFM metric files
+    PFMs = [[stripExt(e),e] for e in sourceList if ext(e) in ("PFM")] # all PFM metric files
+    
+    ## Those lists look like this:
+    ##  ["/some/path/file", "/some/path/file.pfa"]
+    ##  [0] is paf sans extension, [1] is all of it (*)
+    ##  (*) We have to worry about case sensitivity, so I store more data.
+
+    ## Go through the (maybe empty) list of PFA and FPB files
+    for pfab_tup in PFABs:
+        foundAFM = False
+        ## Looking for AFM files
+        for afm_tup in AFMs:
+            if afm_tup[0] == pfab_tup[0]:
+                ## We have found an afm file for this pfa/pfb file
+                ## so make an object
+                fi = Type1Item( pfab_tup[1], metricpaf = afm_tup[1] )
+                listOfItemsGenerated.append( fi )
+                foundAFM = True
+                break
+        ## If we found no AFM then try find a PFM
+        foundPFM = False
+        if not foundAFM:
+            ## Looking for PFM files
+            for pfm_tup in PFMs:
+                if pfm_tup[0] == pfab_tup[0]:
+                    ## We have found pfm file for it, make an object
+                    fi = Type1Item( pfab_tup[1], metricpaf = pfm_tup[1] )
+                    listOfItemsGenerated.append( fi )
+                    foundPFM = True
+                    break
+        ## If we found neither:
+        if not foundAFM and not foundPFM:
+            ## Just make an object without a metric file associated.
+            fi = Type1Item( pfab_tup[1], metricpaf = None )
+            listOfItemsGenerated.append( fi )
+
     ## Do the other font types
     TTFList = [ paf for paf in sourceList if ext(paf) == "TTF" ]
     if len(TTFList) > 0:
         for paf in TTFList:
             fi = TruetypeItem( paf )
-            #if fi.badfont:
-            #    fi = InfoFontItem( "BADFONT", paf )            
             listOfItemsGenerated.append( fi )
                 
     OTFList = [ paf for paf in sourceList if ext(paf) == "OTF" ]
     if len(OTFList) > 0:
         for paf in OTFList:
             fi = OpentypeItem( paf )
-            #if fi.badfont:
-                #fi = InfoFontItem( "BADFONT", paf )              
             listOfItemsGenerated.append(fi)
             
     TTCList = [ paf for paf in sourceList if ext(paf) == "TTC" ]
     if len(TTCList) > 0:
         for paf in TTCList:
             fi = TruetypeCollectionItem( paf )
-            #if fi.badfont:
-                #fi = InfoFontItem( "BADFONT", paf )              
             listOfItemsGenerated.append(fi)
         
     ## Sort the list: not sure this will work....
     listOfItemsGenerated.sort( cmp=locale.strcoll, key=lambda obj:obj.glyphpaf ) # Try to sort on that field.
-    
+
     ## Supply it: This is pure magic!
     for fi in listOfItemsGenerated:
         yield fi
@@ -489,15 +491,13 @@ class Folder(BasicFontList):
                 ## to the app. It won't even become a 'badfont'
                 fpsys.logBadStrings(f) # I'm keeping a list of bad names.
 
-        #print sourceList
-        
         ## Now employ the generator magic:
         for fi in itemGenerator( self, sourceList ):
             self.append(fi)
-            
+        
         if len(self) == 0:
             raise fontybugs.FolderHasNoFonts(self.path)
-#TO DO            
+          
         ## I sorted the list in the generator, so if that didn't work, perhaps this will
         ## self.sort ( locale.strcoll ) # Sort myself....
     def __str__(self):
@@ -505,7 +505,7 @@ class Folder(BasicFontList):
         
     def label( self ):
         """
-        A handy way to refer to Folders to Pogs in certain circumstances.
+        A handy way to refer to Folders & Pogs in certain circumstances.
         See around line 1296 wxgui.OnMainClick()
         Pog.label returns the name
         Folder.label returns the path
@@ -656,9 +656,9 @@ class Pog(BasicFontList):
         ## For Type1 fonts - 
         ## The choice I have made is:
         ## I will ONLY reference the PFB in the Pog file.
-        ## When we install a Pog, the PFM must be sought
+        ## When we install a Pog, the AFM/PFM must be sought
         ## in the original folder and linked.
-        ## For uninstall, simply kill the associated PFM
+        ## For uninstall, simply kill the associated AFM/PFM
         ##
         ## Raises:
         ##          PogEmpty
@@ -683,16 +683,13 @@ class Pog(BasicFontList):
             if not os.path.exists(linkDestination):  
                 if os.path.exists(fi.glyphpaf):
                     os.symlink(fi.glyphpaf, linkDestination)  #Should do the trick.
-                    ## Now, the Type1 special case, link the PFM
-                    ## I could use:
-                    ## myInstance = fi.__class__.__dict__       
-                    ## if "pfmpaf" in myInstance
+                    ## Now, the Type1 special case, link the AFM/PFM
                     if isinstance( fi, Type1Item ):
-                        ## It's a Type 1, does it have a pfmpaf?
-                        if fi.pfmpaf:
+                        ## It's a Type 1, does it have a metricpaf?
+                        if fi.metricpaf:
                             linkDestination = \
-                            os.path.join( self.__pc.userFontPath(), os.path.basename( fi.pfmpaf ) )
-                            os.symlink( fi.pfmpaf, linkDestination )
+                            os.path.join( self.__pc.userFontPath(), os.path.basename( fi.metricpaf ) )
+                            os.symlink( fi.metricpaf, linkDestination )
                 else:
                     bugs += 1
         if bugs == len(self): # There was 100% failure to install fonts.
@@ -730,12 +727,12 @@ class Pog(BasicFontList):
                 if os.path.exists(link):
                     try:
                         os.unlink(link) 
-                        ## The Type1 special case - it's PFM may be here...
+                        ## The Type1 special case - its AFM/PFM may be here...
                         if isinstance( fi, Type1Item ):
-                            ## It's a Type 1, does it have a pfmpaf?
-                            ## It may be None (if this pfb happens not to have had a pfm.)
-                            if fi.pfmpaf:
-                                pfmlink = os.path.join(self.__pc.userFontPath(), os.path.basename(fi.pfmpaf))
+                            ## It's a Type 1, does it have a metricpaf?
+                            ## It may be None (if this pfb happens not to have had a afm/pfm.)
+                            if fi.metricpaf:
+                                pfmlink = os.path.join(self.__pc.userFontPath(), os.path.basename(fi.metricpaf))
                                 if os.path.exists( pfmlink ):
                                     os.unlink( pfmlink )                     
                     except: # e.g. Permission denied [err 13]
