@@ -510,13 +510,21 @@ class FontViewPanel(wx.Panel):
         ## Page choice and Filter controls
         sizerOtherControls = wx.BoxSizer(wx.HORIZONTAL)
 
+        ## The clear filter button: added 10 Jan 2008
+        bmp = wx.Bitmap(fpsys.mythingsdir + "clear.png", type=wx.BITMAP_TYPE_PNG)
+        self.clearButton = wx.BitmapButton(self, -1, bmp, style = wx.NO_BORDER)
+        self.clearButton.SetToolTipString( _("Clear filter") )
+        self.clearButton.Bind( wx.EVT_BUTTON, self.OnClearClick )
+
         self.textFilter = wx.StaticText(self, -1, _("Filter:"))
         self.inputFilter = wx.TextCtrl(self, -1, "")
         self.inputFilter.Bind(wx.EVT_CHAR, self.__evtChar) #catch the enter char
         self.choicePage = wx.Choice(self, -1, choices = ["busy"]) 
         self.choicePage.Bind(wx.EVT_CHOICE, self.__onPagechoiceClick) #Bind choice event
         
+        ## put them into the sizer
         sizerOtherControls.Add(self.textFilter, 0, wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL)
+        sizerOtherControls.Add( self.clearButton, 0, wx.ALIGN_LEFT ) # Clear button
         sizerOtherControls.Add(self.inputFilter, 1, wx.ALIGN_LEFT | wx.EXPAND)
         sizerOtherControls.Add(( 4,-1), 0, wx.EXPAND)
         sizerOtherControls.Add(self.choicePage, 0 ,wx.EXPAND | wx.ALIGN_RIGHT)  #Added it to the sizer
@@ -557,7 +565,16 @@ class FontViewPanel(wx.Panel):
         self.buttMain.Bind(wx.EVT_LEFT_UP,self.__onMainClick) 
     
         ps.sub(toggle_main_button, self.ToggleMainButton) 
-        
+
+    def OnClearClick( self, event ):
+        self.inputFilter.Clear()
+        self.filter = ""
+        ## Now command a change of the view.
+        ## First, return user to page 1:
+        self.pageindex = 1
+        self.__filterAndPageThenCallCreateFitmaps()
+        self.buttMain.SetFocus()  #a GTK bug demands this move. Restore the ESC key func.
+            
     ## Catch the ENTER key in the filter text input control
     def __evtChar(self, e):
         if e.GetKeyCode() == 13:
